Crate kcr_metal3_io

Crate kcr_metal3_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the metal3.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

metal3.io/v1alpha1

  • BareMetalHost
  • BMCEventSubscription
  • DataImage
  • FirmwareSchema
  • HardwareData
  • HostFirmwareComponents
  • HostFirmwareSettings
  • PreprovisioningImage

Modules

v1alpha1