This crate contains kube-rs compatible bindings for Kubernetes custom resources for the metal3.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
metal3.io/v1alpha1
BareMetalHostBMCEventSubscriptionDataImageFirmwareSchemaHardwareDataHostFirmwareComponentsHostFirmwareSettingsPreprovisioningImage